## Functions

<dl>
<dt><a href="#getDefault">getDefault()</a></dt>
<dd><p>Parses the default option value and performs config lookup if needed.</p>
</dd>
<dt><a href="#getMissingOptionError">getMissingOptionError(option)</a></dt>
<dd><p>Prints error message for a missing option on a command. Message also asks for config to be set if default
option value is specified.</p>
</dd>
<dt><a href="#validatePlugin">validatePlugin(path)</a> ⇒ <code>boolean</code></dt>
<dd><p>Validate plugin package info, topics and commands.</p>
</dd>
<dt><a href="#installPlugin">installPlugin(pluginUri, [registryUri])</a> ⇒ <code>Promise</code></dt>
<dd><p>Installs module in tmp dir, validates then copies it into user plugin dir.</p>
</dd>
<dt><a href="#loadPlugins">loadPlugins()</a> ⇒</dt>
<dd><p>Load plugins from ./lib/builtin-plugins/, node_modules and
~/.apiconnect/plugins/node_modules.</p>
</dd>
</dl>

## Typedefs

<dl>
<dt><a href="#PackageDef">PackageDef</a></dt>
<dd></dd>
<dt><a href="#PluginDef">PluginDef</a></dt>
<dd></dd>
<dt><a href="#TopicDef">TopicDef</a></dt>
<dd></dd>
<dt><a href="#OptionDef">OptionDef</a></dt>
<dd></dd>
</dl>

<a name="getDefault"></a>
## getDefault()
Parses the default option value and performs config lookup if needed.

**Kind**: global function  
<a name="getMissingOptionError"></a>
## getMissingOptionError(option)
Prints error message for a missing option on a command. Message also asks for config to be set if default
option value is specified.

**Kind**: global function  
**Throws**:

- Error


| Param | Type |
| --- | --- |
| option | <code>OptionDescription</code> | 

<a name="validatePlugin"></a>
## validatePlugin(path) ⇒ <code>boolean</code>
Validate plugin package info, topics and commands.

**Kind**: global function  

| Param | Type | Description |
| --- | --- | --- |
| path | <code>string</code> | to local plugin directory. |

<a name="installPlugin"></a>
## installPlugin(pluginUri, [registryUri]) ⇒ <code>Promise</code>
Installs module in tmp dir, validates then copies it into user plugin dir.

**Kind**: global function  

| Param | Type | Description |
| --- | --- | --- |
| pluginUri | <code>string</code> | URI for plugin. (passed to npm for installation) |
| [registryUri] | <code>string</code> | Optional URL for npm registry |

<a name="loadPlugins"></a>
## loadPlugins() ⇒
Load plugins from ./lib/builtin-plugins/, node_modules and
~/.apiconnect/plugins/node_modules.

**Kind**: global function  
**Returns**: Array[PluginDef]  
<a name="PackageDef"></a>
## PackageDef
**Kind**: global typedef  

| Param | Type |
| --- | --- |
| name | <code>String</code> | 
| version | <code>String</code> | 

<a name="PluginDef"></a>
## PluginDef
**Kind**: global typedef  

| Type |
| --- |
| <code>[Array.&lt;TopicDef&gt;](#TopicDef)</code> | 

<a name="TopicDef"></a>
## TopicDef
**Kind**: global typedef  

| Param | Type | Description |
| --- | --- | --- |
| name | <code>String</code> |  |
| description | <code>String</code> | One line description for the topic. |
| helpInfo | <code>String</code> &#124; <code>fn</code> | Help text or function that returns help text. |
| commands | <code>Array.&lt;CommandDef&gt;</code> |  |

<a name="OptionDef"></a>
## OptionDef
**Kind**: global typedef  

| Param | Type | Description |
| --- | --- | --- |
| rune | <code>String</code> | One character flag for the option. |
| name | <code>String</code> | One word flag for the option. |
| [optionalValue] | <code>boolean</code> | indicates if value is required. |
| [noValue] | <code>boolean</code> | indicates that no value is expected. |
| [required] | <code>boolean</code> | indicates that either option value or default must be available. |
| [validator] | <code>fn</code> | Function to validate the param value. |
| [type] | <code>String</code> | One of:<br/>* name<br/>* name-version<br/>* name-optversion<br/>* file<br/> * dir<br/>* hostname. |
| [nary] | <code>boolean</code> | indicates option accepts a space seperated list. |
| [mustExist] | <code>boolean</code> | Is type is file or dir, it must exist. |
| [default] | <code>String</code> | value for this option. A value of $APIC_CONFIG$.<key> will lookup the value in APIC config. Eg. $APIC_CONFIG$.catalog.data.organization will lookup the organization from the catalog config. |

